==> ksystemlog-14.12.0.tar.xz: ksystemlog-14.12.0/src/modes/open/openAnalyzer.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _OPEN_ANALYZER_H_
#define _OPEN_ANALYZER_H_


#include <klocale.h>

#include "syslogAnalyzer.h"

#include "logging.h"
#include "logFile.h"

#include "openLogMode.h"

class OpenAnalyzer : public SyslogAnalyzer {
	
	Q_OBJECT
	
	public:
		OpenAnalyzer(LogMode* logMode) :
			SyslogAnalyzer(logMode) {
			
		}
		
		virtual ~OpenAnalyzer() {
			
		}
		
};

#endif

==> ksystemlog-16.12.1.tar.xz: ksystemlog-16.12.1/src/modes/open/openAnalyzer.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _OPEN_ANALYZER_H_
#define _OPEN_ANALYZER_H_

#include "syslogAnalyzer.h"

#include "logging.h"
#include "logFile.h"

#include "openLogMode.h"

class OpenAnalyzer : public SyslogAnalyzer
{
    Q_OBJECT

public:
    OpenAnalyzer(LogMode *logMode)
        : SyslogAnalyzer(logMode)
    {
    }

    virtual ~OpenAnalyzer() {}
};

#endif
